/* Programme de test de fichier de climats pour Unda tempus.
Programm par Maniack Crudelis.
http://www.crudelis.fr
Pour des questions, remarques, suggestions et le support. Rendez-vous sur le forum du site.
Version 1.0. */
/*Copyright (c) 2008 Herv Cottin. Ce fichier fait partie de Unda tempus.

Unda tempus est un logiciel libre; vous pouvez le redistribuer et/ou le modifier selon les termes de la GNU General Public License (Licence Publique Gnrale GNU) telle qu'elle a t publie par la Free Software Foundation; soit la version 3 de la licence, soit (comme vous le souhaitez) toute version ultrieure.

Unda tempus est distribu dans l'espoir qu'il sera utile, mais SANS LA MOINDRE GARANTIE; pas mme la garantie implicite de COMMERCIABILITE ou d'ADEQUATION A UN BUT PARTICULIER.
Voir la GNU General Public License pour plus de dtails.

Vous devriez avoir reu une copie de la GNU General Public License en mme temps que ce programme; sinon, merci d'crire  la Free Software Foundation, Inc, 59 Temple Place, Suite 330, Boston, MA02111-1307 USA.*/

#include <stdio.h>
#include <string.h>
#include "Utilitaire.h"
#include "Fichier.h"

void moteur_principal (FILE* fichiercl, int* erreur, int* avert);   //Moteur de parcours de la table
void Erreur_aff (int* incr, int err_avert, int lignes, const char chaine[255]);

int main (int argc,char *argv[])
{
    FILE* fichiercl;
    FILE* error_log;
    char* nomfichier=NULL;
    int erreur=0, avert=0;
    Titre(argc,argv,"Testeur de fichier de climat","Programme de test de fichier de climat","F8");
    if(argc==1)
    {   /*Le programme n'a pas en argument le nom du fichier, lancement du programme seul*/
        putsacc("Entrez le nom complet du fichier de climat  vrifier\n?: ");
        nomfichier = getsdyn(nomfichier,stdin,0);
    }
    else
    {   //Le programme est lanc avec l'argument (clic droit)
        ER = (int) (nomfichier = (char*) calloc(strlen(argv[1])*2,sizeof(char)));
        Erreur(1);
        strcpy(nomfichier,argv[1]);
    }
    error_log = ouvre_fichier("Erreur.log","w");    //Crer le fichier de log
    fclose(error_log);
    fichiercl = ouvre_fichier(nomfichier,"r");
    printf("Test du fichier de climat en cours.\n\n");
    moteur_principal(fichiercl,&erreur,&avert);
    fclose(fichiercl);
    if (!erreur)
        putsacc("\nLe fichier de climat ne contient aucune erreur.\n");
    else
        printf("\n!!! Le fichier de climat contient %d erreurs\n", erreur);
    if (!avert)
        putsacc("Le fichier de climat ne contient aucun avertissement.\n");
    else
        printf("! Le fichier de climat contient %d avertissements\n", avert);
    free(nomfichier);
    Pause();
    return 0;
}

void moteur_principal (FILE* fichiercl, int* erreur, int* avert)
{
    char ligne[255];
    char chaine[255];
    int lignes=0, verif=1, max_temp, max_vent, i, j, k, val_chiffre, fin_cond, tvp, M, pourc;
    int prec[2][100];
    float valeur1, valeur2;
/*verif:
1:latitude
2:longitude
3:heure d't
4:dcalage horaire
5:heures avant volution mto
6:forage mto
7:Temprature
8:Vent
9:Prcipitation
10:Saison
11:Temprature par saison
12:Causes des prcipitations
13:Horloge vague
*/
    //raz du tableau de prcipitation
    for(i=0;i<100;i++)
        prec[0][i] = 0;
    for(i=0;i<100;i++)
        prec[1][i] = 0;
    while(!feof(fichiercl)) //Boucle sur la totalit du fichier
    {
        fgets(ligne,255,fichiercl); //Prend la ligne qui sera traite
        lignes++;  //Compte le nombre de lignes lues
        //Latitude
        if(lignes == 1)
        {   //la premire ligne doit tre la latitude
            verif++;
            if(!strstr(ligne,"Latitude="))  //La premire ligne ne correspond pas  la latitude
                Erreur_aff(erreur,1,lignes,"La premire ligne doit commencer imprativement par Latitude=\n");
            else
            {   //La premire ligne est bonne
                Efface_char(ligne,"=");
                valeur1 = atof(ligne);  //Lit la latitude
                if(!valeur1)
                    Erreur_aff(avert,2,lignes,"La latitude est nulle, vrifiez que ce n'est pas une erreur\n");
                else if(valeur1 < -65 || valeur1 > 65)
                    Erreur_aff(avert,2,lignes,"La latitude est infrieure  -65 ou suprieure  65, ces valeurs seront brides  -65 ou +65.\n");
            }
        }
        //Longitude
        if(lignes == 2)
        {   //La 2e ligne doit tre la longitude
            verif++;
            if(!strstr(ligne,"Longitude="))   //La 2e ligne ne correspond pas  la Longitude
                Erreur_aff(erreur,1,lignes,"La deuxime ligne doit commencer imprativement par Longitude=\n");
            else
            {   //La deuxime ligne est bonne
                Efface_char(ligne,"=");
                valeur1 = atof(ligne);  //Lit la Longitude
                if(!valeur1)
                    Erreur_aff(avert,2,lignes,"La Longitude est nulle, vrifiez que ce n'est pas une erreur\n");
                else if(valeur1 < -180 || valeur1 > 180)
                    Erreur_aff(avert,2,lignes,"La Longitude est infrieure  -180 ou suprieure  180, ces valeurs seront brides  -180 ou +180.\n");
            }
        }
        //Heure d't
        if(lignes == 3)
        {   //La 3e ligne doit tre l'heure d't
            verif++;
            Efface_char(ligne,"=");
            if(ligne[0] != 'O' && ligne[0] != 'o' && ligne[0] != 'N' && ligne[0] != 'n')
                Erreur_aff(erreur,1,lignes,"Erreur de syntaxe pour l'heure d't. Les rponses acceptes sont O, o, N ou n.\n");
        }
        //Dcalage fuseau horaire
        if(lignes == 4)
        {   //La 4e ligne doit tre le dcalage du fuseau horaire
            verif++;
            Efface_char(ligne,"=");
            valeur1 = atoi(ligne);
            if(valeur1 < -24 || valeur1 > 24)
                Erreur_aff(avert,2,lignes,"La valeur de dcalage horaire semble anormalement leve\n");
        }
        //Nombre heure avant chg mto
        if(lignes == 5)
        {   //La 5e ligne doit tre le nombre d'heure avant chg de mto
            verif++;
            Efface_char(ligne,":");
            valeur1 = atoi(ligne);
            Efface_char(ligne,"-");
            valeur2 = atoi(ligne);
            if(valeur2 < valeur1)
                Erreur_aff(erreur,1,lignes,"Pour le temps avant changement de mto, la deuxime valeur est infrieure  la premire\n");
            if(valeur2 == valeur1)
                Erreur_aff(avert,2,lignes,"Pour le temps avant changement de mto, les 2 valeurs sont identique, vrifiez que ce n'est pas une erreur\n");
        }
        //Changement forc de mto
        if(lignes == 6)
        {   //La 6e ligne doit tre l'indicateur de changement forc
            verif++;
            Efface_char(ligne,":");
            valeur1 = atoi(ligne);
            if(!valeur1)
                Erreur_aff(avert,2,lignes,"Le nombre de fois avant changement de mto forc est nul, vrifiez que ce n'est pas une erreur\n");
        }
        //Temprature
        if(verif == 7)
        {
            verif++;
            while(ligne[0] != '>')
            {   //Trouve la premire occurence de > en dbut de ligne, pour trouver le premier paragraphe
                fgets(ligne,255,fichiercl); //Prend la ligne qui sera traite
                lignes++;  //Compte le nombre de lignes lues
            };
            if(!strstr(ligne,">Temprature:"))   //Le premier paragraphe commenant par > doit tre celui de la temprature
                Erreur_aff(erreur,1,lignes,"Le premier paragraphe aprs #Affichage: doit tre celui de la temprature et commencer par >Temprature:\n");
            //La ligne suivante doit tre celle des proba de variation
            fgets(ligne,255,fichiercl); //Prend la ligne qui sera traite
            lignes++;  //Compte le nombre de lignes lues
            Efface_char(ligne,":");
            valeur1 = atoi(ligne);
            Efface_char(ligne,"/");
            valeur2 = atoi(ligne);
            if(valeur2 < valeur1)
                Erreur_aff(erreur,1,lignes,"Pour les probabilits de variation de temprature, la deuxime valeur est infrieure  la premire\n");
            if(valeur2 == valeur1)
                Erreur_aff(avert,2,lignes,"Pour les probabilits de variation de temprature, les 2 valeurs sont identique, vrifiez que ce n'est pas une erreur\n");
            if(valeur2 > 100)
                Erreur_aff(avert,2,lignes,"Pour les probabilits de variation du temprature, la deuxime valeur est suprieure  100.\n");
            //Vrification de la liste de temprature
            fgets(ligne,255,fichiercl); //Prend la ligne qui sera traite
            lignes++;  //Compte le nombre de lignes lues
            if(ligne[0] != '1')
                Erreur_aff(erreur,1,lignes,"La premire temprature de la liste ne commence pas par 1.\n");
            valeur2=0;
            do
            {
                valeur1 = atoi(ligne);
                if(valeur1 != valeur2+1)
                    Erreur_aff(erreur,1,lignes,"Le numro de la temprature ne suit pas le prcdent avec un pas de 1.\n");
                valeur2=valeur1;    //La valeur actuelle devient la valeur prcdente, pour le prochain tour de boucle.
                Efface_char(ligne,":");
                if(ligne[0] != 'f')   //Si on trouve pas f aprs le premier :
                    Erreur_aff(erreur,1,lignes,"Juste aprs le premier : impossible de trouver le f qui prcde le numro d'effet.\n");
                if(!isdigit(ligne[1]))   //Si aprs f il n'y a pas un chiffre
                    Erreur_aff(erreur,1,lignes,"Impossible de trouver le numro d'effet li  cette temprature.\n");
                if(!strstr(ligne,":"))
                    Erreur_aff(erreur,1,lignes,"Impossible de trouver le deuxime : qui prcde l'affichage de la temprature.\n");
                fgets(ligne,255,fichiercl); //Prend la ligne qui sera traite
                lignes++;  //Compte le nombre de lignes lues
            }while(isdigit(ligne[0])); //Jusqu' ce que la ligne ne commence plus par un chiffre (ce devrait tre <)
            max_temp = valeur1; //La temprature maximale correspond  la valeur de la dernire ligne.
            if(ligne[0] != '<')
                Erreur_aff(erreur,1,lignes,"La liste de temprature devrait se terminer par <.\n");
        }
        //Vent
        if(verif == 8)
        {
            verif++;
            while(ligne[0] != '>')
            {   //Trouve la deuxime occurence de > en dbut de ligne, pour trouver le deuxime paragraphe
                fgets(ligne,255,fichiercl); //Prend la ligne qui sera traite
                lignes++;  //Compte le nombre de lignes lues
            };
            if(!strstr(ligne,">Vent:"))   //Le deuxime paragraphe commenant par > doit tre celui du vent
                Erreur_aff(erreur,1,lignes,"Le deuxime paragraphe aprs #Affichage: doit tre celui du vent et commencer par >Vent:\n");
            //La ligne suivante doit tre celle des proba de variation
            fgets(ligne,255,fichiercl); //Prend la ligne qui sera traite
            lignes++;  //Compte le nombre de lignes lues
            Efface_char(ligne,":");
            valeur1 = atoi(ligne);
            Efface_char(ligne,"/");
            valeur2 = atoi(ligne);
            if(valeur2 < valeur1)
                Erreur_aff(erreur,1,lignes,"Pour les probabilits de variation du vent, la deuxime valeur est infrieure  la premire\n");
            if(valeur2 == valeur1)
                Erreur_aff(avert,2,lignes,"Pour les probabilits de variation du vent, les 2 valeurs sont identique, vrifiez que ce n'est pas une erreur\n");
            if(valeur2 > 100)
                Erreur_aff(avert,2,lignes,"Pour les probabilits de variation du vent, la deuxime valeur est suprieure  100.\n");
            //Vrification de la liste des vents
            fgets(ligne,255,fichiercl); //Prend la ligne qui sera traite
            lignes++;  //Compte le nombre de lignes lues
            if(ligne[0] != '1')
                Erreur_aff(erreur,1,lignes,"Le premier vent de la liste ne commence pas par 1.\n");
            valeur2=0;
            do
            {
                valeur1 = atoi(ligne);
                if(valeur1 != valeur2+1)
                    Erreur_aff(erreur,1,lignes,"Le numro du vent ne suit pas le prcdent avec un pas de 1.\n");
                valeur2=valeur1;    //La valeur actuelle devient la valeur prcdente, pour le prochain tour de boucle.
                Efface_char(ligne,":");
                if(ligne[0] != 't')   //Si on trouve pas t aprs le premier :
                    Erreur_aff(erreur,1,lignes,"Juste aprs le premier :, impossible de trouver le t qui prcde la variation de temprature.\n");
                if(!isdigit(ligne[1]) && ligne[1] != '-' && ligne[1] != '+')   //Si aprs t il n'y a pas un chiffre, un - ou un +
                    Erreur_aff(erreur,1,lignes,"Impossible de trouver la variation de temprature li  ce vent.\n");
                else if(ligne[1] == '-' || ligne[1] == '+')
                {   //En cas de - ou de +
                    if(!isdigit(ligne[2]))   //Vrifie qu'il y ai bien un chiffre aprs
                        Erreur_aff(erreur,1,lignes,"Impossible de trouver la variation de temprature li  ce vent.\n");
                }
                Efface_char(ligne,":");
                if(ligne[0] != 'f')   //Si on trouve pas f aprs le deuxime :
                    Erreur_aff(erreur,1,lignes,"Juste aprs le deuxime :, impossible de trouver le f qui prcde le numro d'effet.\n");
                if(!isdigit(ligne[1]))   //Si aprs f il n'y a pas un chiffre
                    Erreur_aff(erreur,1,lignes,"Impossible de trouver le numro d'effet li  ce vent.\n");
                if(!strstr(ligne,":"))
                    Erreur_aff(erreur,1,lignes,"Impossible de trouver le troisime :, qui prcde l'affichage de ce vent.\n");
                fgets(ligne,255,fichiercl); //Prend la ligne qui sera traite
                lignes++;  //Compte le nombre de lignes lues
            }while(isdigit(ligne[0])); //Jusqu' ce que la ligne ne commence plus par un chiffre (ce devrait tre <)
            max_vent = valeur1; //La temprature maximale correspond  la valeur de la dernire ligne.
            if(ligne[0] != '<')
                Erreur_aff(erreur,1,lignes,"La liste des vents devrait se terminer par <.\n");
        }
        //Prcipitation
        if(verif == 9)
        {
            verif++;
            while(ligne[0] != '>')
            {   //Trouve la troisime occurence de > en dbut de ligne, pour trouver le troisime paragraphe
                fgets(ligne,255,fichiercl); //Prend la ligne qui sera traite
                lignes++;  //Compte le nombre de lignes lues
            };
            if(!strstr(ligne,">Prcipitation:"))   //Le troisime paragraphe commenant par > doit tre celui des prcipitation
                Erreur_aff(erreur,1,lignes,"Le troisime paragraphe aprs #Affichage: doit tre celui des prcipitation et commencer par >Prcipitation:\n");
            //La ligne suivante doit tre celle des proba de variation
            fgets(ligne,255,fichiercl); //Prend la ligne qui sera traite
            lignes++;  //Compte le nombre de lignes lues
            Efface_char(ligne,":");
            valeur1 = atoi(ligne);
            Efface_char(ligne,"/");
            valeur2 = atoi(ligne);
            if(valeur2 < valeur1)
                Erreur_aff(erreur,1,lignes,"Pour les probabilits de variation des prcipitations, la deuxime valeur est infrieure  la premire\n");
            if(valeur2 == valeur1)
                Erreur_aff(avert,2,lignes,"Pour les probabilits de variation des prcipitations, les 2 valeurs sont identique, vrifiez que ce n'est pas une erreur\n");
            if(valeur2 > 100)
                Erreur_aff(avert,2,lignes,"Pour les probabilits de variation du prcipitations, la deuxime valeur est suprieure  100.\n");
            //Vrification de la liste des prcipitations
            fgets(ligne,255,fichiercl); //Prend la ligne qui sera traite
            lignes++;  //Compte le nombre de lignes lues
            i=1;
            do
            {
                valeur1 = atoi(ligne);  //Place la valeur de cette prcipitation dans le tableau de prcipitation
                for(j=1;j<i+1;j++)
                {   //Boucle sur le nombre de valeur dj inscrite dans le tableau
                    if(valeur1 == prec[0][j])
                        Erreur_aff(avert,2,lignes,"Cette prcipitation utilise un numro dj utilis dans la liste de prcipitation.\n");
                }
                prec[0][i++] = valeur1;
                Efface_char(ligne,":");
                if(ligne[0] != 't')   //Si on trouve pas t aprs le premier :
                    Erreur_aff(erreur,1,lignes,"Juste aprs le premier :, impossible de trouver le t qui prcde la variation de temprature.\n");
                if(!isdigit(ligne[1]) && ligne[1] != '-' && ligne[1] != '+')   //Si aprs t il n'y a pas un chiffre, un - ou un +
                    Erreur_aff(erreur,1,lignes,"Impossible de trouver la variation de temprature li  cette prcipitation.\n");
                else if(ligne[1] == '-' || ligne[1] == '+')
                {   //En cas de - ou de +
                    if(!isdigit(ligne[2]))   //Vrifie qu'il y ai bien un chiffre aprs
                        Erreur_aff(erreur,1,lignes,"Impossible de trouver la variation de temprature li  cette prcipitation.\n");
                }
                Efface_char(ligne,":");
                if(ligne[0] != 'f')   //Si on trouve pas f aprs le deuxime :
                    Erreur_aff(erreur,1,lignes,"Juste aprs le deuxime :, impossible de trouver le f qui prcde le numro d'effet.\n");
                if(!isdigit(ligne[1]))   //Si aprs f il n'y a pas un chiffre
                    Erreur_aff(erreur,1,lignes,"Impossible de trouver le numro d'effet li  cette prcipitation.\n");
                if(!strstr(ligne,":"))
                    Erreur_aff(erreur,1,lignes,"Impossible de trouver le troisime :, qui prcde l'affichage de cette prcipitation.\n");
                fgets(ligne,255,fichiercl); //Prend la ligne qui sera traite
                lignes++;  //Compte le nombre de lignes lues
            }while(isdigit(ligne[0])); //Jusqu' ce que la ligne ne commence plus par un chiffre (ce devrait tre <)
            prec[0][0] = i-1;
            if(ligne[0] != '<')
                Erreur_aff(erreur,1,lignes,"La liste des prcipitation devrait se terminer par <.\n");
        }
        //Saison
        if(verif == 10)
        {
            verif++;
            while(ligne[0] != '>')
            {   //Trouve la quatrime occurence de > en dbut de ligne, pour trouver le quatrime paragraphe
                fgets(ligne,255,fichiercl); //Prend la ligne qui sera traite
                lignes++;  //Compte le nombre de lignes lues
            };
            if(!strstr(ligne,">Saison:"))   //Le quatrime paragraphe commenant par > doit tre celui des saison
                Erreur_aff(erreur,1,lignes,"Le quatrime paragraphe aprs #Affichage: doit tre celui des saison et commencer par >Saison:\n");
            for(i=0;i<4;i++)
            {
                fgets(ligne,255,fichiercl); //Prend la ligne qui sera traite
                lignes++;  //Compte le nombre de lignes lues
                if(ligne[0]-48 != i+1)
                    Erreur_aff(erreur,1,lignes,"La numrotation des saisons est incorrecte.\n");
                if(ligne[1] != ':')
                    Erreur_aff(erreur,1,lignes,"Impossible de trouver le : qui prcde l'affichage de la saison.\n");
            }
            fgets(ligne,255,fichiercl); //Prend la ligne qui sera traite
            lignes++;  //Compte le nombre de lignes lues
            if(ligne[0] != '<')
            {
                if(isdigit(ligne[0]))
                    Erreur_aff(erreur,1,lignes,"La liste des saisons ne doit contenir que 4 saisons.\n");
                else
                    Erreur_aff(erreur,1,lignes,"La liste de 4 saisons doit se terminer par un <.\n");
            }
        }
        //Temprature par saison
        if(verif == 11)
        {
            verif++;
            while(ligne[0] != '>')
            {   //Trouve la cinquime occurence de > en dbut de ligne, pour trouver le cinquime paragraphe
                fgets(ligne,255,fichiercl); //Prend la ligne qui sera traite
                lignes++;  //Compte le nombre de lignes lues
            };
            if(!strstr(ligne,">Temprature par saison:"))   //Le cinquime paragraphe commenant par > doit tre celui des saison
                Erreur_aff(erreur,1,lignes,"Le cinquime paragraphe aprs #Affichage: doit tre celui des temprature par saison et commencer par >Temprature par saison:\n");
            for(i=0;i<4;i++)
            {
                fgets(ligne,255,fichiercl); //Prend la ligne qui sera traite
                lignes++;  //Compte le nombre de lignes lues
                if(ligne[1]-48 != i+1)
                    Erreur_aff(erreur,1,lignes,"La numrotation des saisons est incorrecte.\n");
                if(ligne[2] != '=')
                    Erreur_aff(erreur,1,lignes,"Impossible de trouver le = qui prcde les tempratures minimale et maximale.\n");
                Efface_char(ligne,"=");
                if(ligne[0] != 't')
                    Erreur_aff(erreur,1,lignes,"Impossible de trouver le t qui prcde la temprature minimale.\n");
                Efface_char(ligne,"t");
                valeur1 = atoi(ligne);
                if(valeur1 < 1 || valeur1 > max_temp)
                    Erreur_aff(erreur,1,lignes,"La valeur de temprature minimale dpasse les limites admises.\n");
                Efface_char(ligne,",");
                if(ligne[0] != 't')
                    Erreur_aff(erreur,1,lignes,"Impossible de trouver le t qui prcde la temprature maximale.\n");
                Efface_char(ligne,"t");
                valeur2 = atoi(ligne);
                if(valeur2 < 1 || valeur2 > max_temp)
                    Erreur_aff(erreur,1,lignes,"La valeur de temprature maximale dpasse les limites admises.\n");
                if(valeur2 < valeur1)
                    Erreur_aff(erreur,1,lignes,"La valeur de temprature maximale est infrieure  la valeur de temprature minimale.\n");
            }
            fgets(ligne,255,fichiercl); //Prend la ligne qui sera traite
            lignes++;  //Compte le nombre de lignes lues
            if(ligne[0] != '<')
            {
                if(isdigit(ligne[0]))
                    Erreur_aff(erreur,1,lignes,"La liste des saisons ne doit contenir que 4 saisons.\n");
                else
                    Erreur_aff(erreur,1,lignes,"La liste de 4 saisons doit se terminer par un <.\n");
            }
        }
        //Causes des prcipitations
        if(verif == 12)
        {
            verif++;
            while(ligne[0] != '>')
            {   //Trouve la sixime occurence de > en dbut de ligne, pour trouver le sixime paragraphe
                fgets(ligne,255,fichiercl); //Prend la ligne qui sera traite
                lignes++;  //Compte le nombre de lignes lues
            };
            if(!strstr(ligne,">Causes des prcipitations:"))   //Le sixime paragraphe commenant par > doit tre celui des prcipitations
                Erreur_aff(erreur,1,lignes,"Le sixime paragraphe aprs #Affichage: doit tre celui des causes de prcipitation et commencer par >Causes des prcipitations:\n");
            //Vrification des lignes de causes de prcipitations
            fgets(ligne,255,fichiercl); //Prend la ligne qui sera traite
            lignes++;  //Compte le nombre de lignes lues
            do
            {
                pourc=0;    //Initialisation du dernier pourcentage lu pour le moteur M6
                while(!isdigit(ligne[0]))
                {   //Saute les lignes de commentaires et texte
                    fgets(ligne,255,fichiercl); //Prend la ligne qui sera traite
                    lignes++;  //Compte le nombre de lignes lues
                };
                valeur1 = atoi(ligne);  //Lit le numro de la prcipitation traite  cette ligne
                for(i=1;i<=prec[0][0];i++)
                {
                    if(valeur1 == prec[0][i])  //Si le numro de prcipitation est trouv dans le tableau de prcipitation, la prcipitation est rpertorie.
                        i=prec[0][0]+9;   //Quitte la boucle et donne  i une valeur singulire
                }
                if(i != prec[0][0]+10)
                {
                    sprintf(chaine,"La prcipitation %.0f n'est pas rpertorie dans la liste des prcipitations. Cette ligne ne sera pas utilise par le programme.\n",valeur1);
                    Erreur_aff(avert,2,lignes,chaine);
                }
                Efface_char(ligne,"=");
                fin_cond=0;        //Indiquera une ventuelle erreur qui provoque la fin de vrif des conditions
                if(ligne[0] == '[')
                {   //Prsence de conditions pour cette ligne de prcipitation
                    Efface_char(ligne,"[");
                    do
                    {
                        val_chiffre = 1; //Par dfaut considre qu'il devra sauter des valeurs numriques
                        if(ligne[0] != 't' && ligne[0] != 'v' && ligne[0] != 'p')
                            Erreur_aff(erreur,1,lignes,"Les conditions de prcipitations doivent commencer par t, v ou p (en minuscule).\n");
                        else
                        {
                            if(ligne[0] == 't')
                            {
                                tvp = 1;    //Temprature
                                Efface_char(ligne,"t");
                                if(isdigit(ligne[0]))   //Si c'est un chiffre
                                {
                                    valeur2 = atoi(ligne);  //Lit le numro de la temprature
                                    if(valeur2 > max_temp)
                                    {
                                        sprintf(chaine,"La temprature %.0f n'existe pas.\n", valeur2);
                                        Erreur_aff(erreur,1,lignes,chaine);
                                    }
                                }
                                else if (ligne[0] != 'a' && ligne[0] != 'b') //Si ce n'est pas un chiffre, vrifie si c'est a ou b
                                    Erreur_aff(erreur,1,lignes,"Aprs t, on peut trouver un chiffre ou a (pour augmentation) ou b (pour baisse), rien d'autre.\n");
                                else
                                    val_chiffre=0;  //C'est a ou b, val_chiffre passe  0 pour indiquer qu'il devra sauter une seule lettre
                            }
                            else if(ligne[0] == 'v')
                            {
                                tvp = 2;    //Vent
                                Efface_char(ligne,"v");
                                if(isdigit(ligne[0]))   //Si c'est un chiffre
                                {
                                    valeur2 = atoi(ligne);  //Lit le numro du vent
                                    if(valeur2 > max_vent)
                                    {
                                        sprintf(chaine,"Le vent %.0f n'existe pas.\n", valeur2);
                                        Erreur_aff(erreur,1,lignes,chaine);
                                    }
                                }
                                else if (ligne[0] != 'a' && ligne[0] != 'b') //Si ce n'est pas un chiffre, vrifie si c'est a ou b
                                    Erreur_aff(erreur,1,lignes,"Aprs v, on peut trouver un chiffre ou a (pour augmentation) ou b (pour baisse), rien d'autre.\n");
                                else
                                    val_chiffre=0;  //C'est a ou b, val_chiffre passe  0 pour indiquer qu'il devra sauter une seule lettre
                            }
                            else if(ligne[0] == 'p')
                            {
                                tvp = 3;    //Prcipitation
                                Efface_char(ligne,"p");
                                if(isdigit(ligne[0]))   //Si c'est un chiffre
                                {
                                    valeur2 = atoi(ligne);  //Lit le numro de la prcipitation
                                    for(i=1;i<=prec[0][0];i++)
                                    {
                                        if(valeur2 == prec[0][i])  //Si le numro de prcipitation est trouv dans le tableau de prcipitation, la prcipitation est rpertorie.
                                            i=prec[0][0]+9;   //Quitte la boucle et donne  i une valeur singulire
                                    }
                                    if(i != prec[0][0]+10)
                                    {
                                        sprintf(chaine,"La prcipitation %.0f n'est pas rpertorie dans la liste des prcipitations.\n", valeur2);
                                        Erreur_aff(erreur,1,lignes,chaine);
                                    }
                                }
                                else
                                    Erreur_aff(erreur,1,lignes,"Aprs p, on doit trouver un chiffre.\n");
                            }
                            //Passe  la suite des conditions
                            i=0;
                            if(!val_chiffre)    //a ou b
                                i++;    //Saute simplement la lettre
                            else
                                while(isdigit(ligne[++i])); //Sinon saute tous les chiffres
                            if(ligne[i] != '-' && ligne[i] != '+' && ligne[i] != ']')
                            {
                                Erreur_aff(erreur,1,lignes,"Aprs un chiffre ou a et b, on attend -, + ou ].\n");
                                fin_cond=1;
                            }
                            else
                            {
                                if(ligne[i] == '-')
                                {
                                    if(!val_chiffre)
                                        Erreur_aff(erreur,1,lignes,"Pas de plage de valeur aprs a ou b.\n");
                                    if(!isdigit(ligne[i+1]))
                                        Erreur_aff(erreur,1,lignes,"Pour la plage de valeur, - doit tre suivi d'un chiffre.\n");
                                    Efface_char(ligne,"-");
                                    valeur2 = atoi(ligne);  //Lit la 2e valeur numrique de la plage de valeur (de temprature, vent ou prcipitation)
                                    if(tvp == 1)    //Temprature
                                    {
                                        if(valeur2 > max_temp)
                                        {
                                            sprintf(chaine,"La temprature %.0f n'existe pas.\n", valeur2);
                                            Erreur_aff(erreur,1,lignes,chaine);
                                        }
                                    }
                                    if(tvp == 2)    //Vent
                                    {
                                        if(valeur2 > max_vent)
                                        {
                                            sprintf(chaine,"Le vent %.0f n'existe pas.\n", valeur2);
                                            Erreur_aff(erreur,1,lignes,chaine);
                                        }
                                    }
                                    if(tvp == 3)    //Prcipitation
                                    {
                                        for(i=1;i<=prec[0][0];i++)
                                        {
                                            if(valeur2 == prec[0][i])  //Si le numro de prcipitation est trouv dans le tableau de prcipitation, la prcipitation est rpertorie.
                                                i=prec[0][0]+9;   //Quitte la boucle et donne  i une valeur singulire
                                        }
                                        if(i != prec[0][0]+10)
                                        {
                                            sprintf(chaine,"La prcipitation %.0f n'est pas rpertorie dans la liste des prcipitations.\n", valeur2);
                                            Erreur_aff(erreur,1,lignes,chaine);
                                        }
                                    }
                                    i=0;
                                    while(isdigit(ligne[++i])); //Saute tous les chiffres
                                    for(;i>0;i--)
                                    {
                                        for(j=0;j<(int)strlen(ligne);j++)
                                            ligne[j] = ligne[j+1];
                                    }
                                }
                                if(ligne[i] == '+')
                                {
                                    if(isdigit(ligne[i+1]))
                                        Erreur_aff(erreur,1,lignes,"Aprs +, on doit trouver p, v ou t.\n");
                                    Efface_char(ligne,"+");
                                }
                                if(ligne[i] == ']')
                                {
                                    for(;i>0;i--)
                                    {
                                        for(j=0;j<(int)strlen(ligne);j++)
                                            ligne[j] = ligne[j+1];  //Efface tout jusqu' ]
                                    }
                                }
                            }
                        }
                    }while(ligne[0] != ']' && !fin_cond);
                    if(ligne[0] == ']')
                        Efface_char(ligne,"]");
                }
                else   //Pas de condition a cette ligne.
                    prec[1][(int)valeur1] = 1; //Une ligne sans condition valide pour cette prcipitation
                if(!fin_cond)    //si fin_cond est  1, erreur dans la vrif des conditions. Le reste de la ligne n'est pas traite
                {
                    //Reconnaissance du moteur utilis
                    if(!strstr(ligne,"%"))  //Pas de %
                        M=5;
                    else if(strstr(ligne,"%%")) //2 % -> %%
                        M=4;
                    else
                        M=6;
                    if(!strstr(ligne,"."))  //Pas de . sur la ligne!
                        Erreur_aff(erreur,1,lignes,"Les rgles de prcipitations doivent imprativement se terminer par un .\n");
                    if(M==4 || M==5)    //Test du /\ pour M4 et M5
                    {   //Pour M4 et M5, /\ est indispensable
                        if(!strstr(ligne,"/\\"))
                            Erreur_aff(erreur,1,lignes,"/\\ est indispensable pour les moteurs M4 et M5.\n");
                    }
                    if(ligne[0] != 'd' && !isdigit(ligne[0]))   //Si le 1er caractre est diffrent de d ou d'un chiffre, erreur
                        Erreur_aff(erreur,1,lignes,"Aprs = et les ventuelles conditions, la rgle de prcipitation doit commencer par un chiffre ou d{...}\n");
                    else //Si pas d'erreur, on peut continuer
                    {
                        do
                        {
                            fin_cond=0;
                            if(ligne[0] == 'd')
                            {   //Traitement de la commande dx{}
                                if(M == 6)
                                    Erreur_aff(erreur,1,lignes,"M6: Le moteur M6 ne prend pas en charge la syntaxe dx{}, il faut utiliser les moteurs M4 ou M5\n");
                                Efface_char(ligne,"d");
                                i = atoi(ligne);    //Lit le nombre de valeur qui doit tre prsent dans le champs d
                                j=0;
                                while(isdigit(ligne[j++])); //Saute toutes les chiffres
                                if(ligne[j-1] != '{')
                                    Erreur_aff(erreur,1,lignes,"Aprs dx, on doit trouver {\n");
                                else
                                {
                                    Efface_char(ligne,"{");
                                    do
                                    {
                                        valeur2 = atoi(ligne);  //Lit la prcipitation
                                        i--;    //Une valeur prsente sur les i qui doivent tre trouves
                                        for(j=1;j<=prec[0][0];j++)  //Et vrifie son existence
                                        {
                                            if(valeur2 == prec[0][j])  //Si le numro de prcipitation est trouv dans le tableau de prcipitation, la prcipitation est rpertorie.
                                                j=prec[0][0]+9;   //Quitte la boucle et donne  i une valeur singulire
                                        }
                                        if(j != prec[0][0]+10)
                                        {
                                            sprintf(chaine,"La prcipitation %.0f n'est pas rpertorie dans la liste des prcipitations.\n", valeur2);
                                            Erreur_aff(erreur,1,lignes,chaine);
                                        }
                                        j=0;
                                        while(isdigit(ligne[j++])); //Saute toutes les chiffres
                                        while(ligne[j-1] == ';')
                                        {   //prsence d'un v ou t en plus de la prcipitation
                                            Efface_char(ligne,";");
                                            if(ligne[0] != 'v' && ligne[0] != 't')
                                                Erreur_aff(erreur,1,lignes,"Seul v ou t sont accepts en plus d'une prcipitation aprs un ;\n");
                                            if(ligne[0] == 'v')
                                            {
                                                Efface_char(ligne,"v");
                                                tvp=2;
                                            }
                                            if(ligne[0] == 't')
                                            {
                                                Efface_char(ligne,"t");
                                                tvp=1;
                                            }
                                            valeur2 = atoi(ligne);  //Lit la valeur numrique de temprature ou vent
                                            if(tvp == 1)    //Temprature
                                            {
                                                if(valeur2 > max_temp)
                                                {
                                                    sprintf(chaine,"La temprature %.0f n'existe pas.\n", valeur2);
                                                    Erreur_aff(erreur,1,lignes,chaine);
                                                }
                                            }
                                            if(tvp == 2)    //Vent
                                            {
                                                if(valeur2 > max_vent)
                                                {
                                                    sprintf(chaine,"Le vent %.0f n'existe pas.\n", valeur2);
                                                    Erreur_aff(erreur,1,lignes,chaine);
                                                }
                                            }
                                            j=0;
                                            while(isdigit(ligne[j++])); //Saute toutes les chiffres
                                        }
                                        if(ligne[j-1] != ',' && ligne[j-1] != '}')
                                            Erreur_aff(erreur,1,lignes,"Erreur dans la syntaxe de dx{}, aprs une valeur on attend , ou }\n");
                                        if(ligne[j-1] == ',')
                                        {
                                            Efface_char(ligne,","); //Efface la , pour que la boucle lise la valeur suivante
                                            j=1;    //Force le while de fin  lire la valeur  ligne[0]
                                        }
                                        else if(ligne[j-1] != '}')
                                            ligne[j-1] = '}';   //Afin d'viter une erreur de boucle infinie, on force le } dans la chaine.
                                    }while(ligne[j-1] != '}');  //Termine la commande dx{} sur le } final
                                    Efface_char(ligne,"}"); //Efface la commande dx{} qui vient d'tre lue.
                                    if(i)
                                    {   //Si i!=0, erreur sur le nombre de valeur dans la commande dx{}
                                        if(i<0)
                                            Erreur_aff(erreur,1,lignes,"Dans la commande dx{}, le programme a trouv plus de x valeurs.\n");
                                        if(i>0)
                                            Erreur_aff(erreur,1,lignes,"Dans la commande dx{}, le programme a trouv moins de x valeurs.\n");
                                    }
                                }
                            }    //Pas de commande dx{}, on passe  la suite
                            else if(isdigit(ligne[0])) //Test d'une valeur numrique
                            {
                                valeur2 = atoi(ligne);  //Lit la prcipitation
                                for(j=1;j<=prec[0][0];j++)  //Et vrifie son existence
                                {
                                    if(valeur2 == prec[0][j])  //Si le numro de prcipitation est trouv dans le tableau de prcipitation, la prcipitation est rpertorie.
                                        j=prec[0][0]+9;   //Quitte la boucle et donne  i une valeur singulire
                                }
                                if(j != prec[0][0]+10)
                                {
                                    sprintf(chaine,"La prcipitation %.0f n'est pas rpertorie dans la liste des prcipitations.\n", valeur2);
                                    Erreur_aff(erreur,1,lignes,chaine);
                                }
                                j=0;
                                while(isdigit(ligne[j++])); //Saute toutes les chiffres
                                while(ligne[j-1] == ';')
                                {   //prsence d'un v ou t en plus de la prcipitation
                                    Efface_char(ligne,";");
                                    if(ligne[0] != 'v' && ligne[0] != 't')
                                        Erreur_aff(erreur,1,lignes,"Seul v ou t sont accepts en plus d'une prcipitation aprs un ;\n");
                                    if(ligne[0] == 'v')
                                    {
                                        Efface_char(ligne,"v");
                                        tvp=2;
                                    }
                                    if(ligne[0] == 't')
                                    {
                                        Efface_char(ligne,"t");
                                        tvp=1;
                                    }
                                    valeur2 = atoi(ligne);  //Lit la valeur numrique de temprature ou vent
                                    if(tvp == 1)    //Temprature
                                    {
                                        if(valeur2 > max_temp)
                                        {
                                            sprintf(chaine,"La temprature %.0f n'existe pas.\n", valeur2);
                                            Erreur_aff(erreur,1,lignes,chaine);
                                        }
                                    }
                                    if(tvp == 2)    //Vent
                                    {
                                        if(valeur2 > max_vent)
                                        {
                                            sprintf(chaine,"Le vent %.0f n'existe pas.\n", valeur2);
                                            Erreur_aff(erreur,1,lignes,chaine);
                                        }
                                    }
                                    j=0;
                                    while(isdigit(ligne[j++])); //Saute tout les chiffres
                                }
                                if(ligne[j-1] == '%')   //% du moteur M6
                                {
                                    if(M!=6 && ligne[j]!='%')   //Si c'est un % seul, seul M6 l'accepte
                                        Erreur_aff(erreur,1,lignes,"Seul le moteur M6 accepte la prsence du % aprs chaque valeur.\n");
                                    Efface_char(ligne,"%");
                                    valeur2 = atoi(ligne);    //Lit le pourcentage pour cette prcipitation
                                    if(valeur2 <= pourc)
                                        Erreur_aff(avert,2,lignes,"Les pourcentages se chevauchent, des prcipitations seront ignores.\n");
                                    if(valeur2 > 100)
                                        Erreur_aff(avert,2,lignes,"Les pourcentages dpassent 100%%, ils seront ignors.\n");
                                    pourc = valeur2;
                                }
                                else if(M==6)
                                    Erreur_aff(erreur,1,lignes,"Le moteur M6 ncessite la prsence du % aprs chaque valeur.\n");
                                while(isdigit(ligne[0])) //Efface tout les chiffres
                                {
                                    for(j=0;j<(int)strlen(ligne);j++)
                                        ligne[j] = ligne[j+1];
                                };
                            }
                            else //Pas non plus une valeur numrique, erreur rien n'est reconnu
                            {
                                Erreur_aff(erreur,1,lignes,"Erreur de syntaxe, le programme ne trouve pas la suite des rgles de prcipitation.\n");
                                fin_cond=1; //Arrt de la vrification de la ligne
                            }
                            //Fin de boucle, vrification des informations aprs la lecture d'une valeur
                            if(ligne[0] != ',' && ligne[0] != '/' && ligne[0] != '.' && ligne[0] != '%')
                            {
                                Erreur_aff(erreur,1,lignes,"Aprs une valeur lue, on attend , /\\ . ou %%.\n");
                                fin_cond=1; //Arrt de la vrification de la ligne
                            }
                            else    //Pas d'erreurs, test des diffrents mots cls
                            {
                                if(ligne[0] == ',') // ,
                                {   //Virgule, la ligne continue
                                    Efface_char(ligne,",");
                                }
                                if(ligne[0] == '/') // slash-antislash
                                {   // slash-antislash, on passe au champs de dgradation des prcipitations
                                    if(ligne[1] != '\\')
                                    {
                                        Erreur_aff(erreur,1,lignes,"/ doit tre suivi de \\.\n");
                                        Efface_char(ligne,"/");
                                    }
                                    else
                                        Efface_char(ligne,"\\");
                                }
                                if(ligne[0] == '.') // .
                                    fin_cond=1; //La ligne se termine
                                if(ligne[0] == '%') // %%
                                {
                                    if(M!=4)
                                        Erreur_aff(erreur,1,lignes,"Seul le moteur M4 traite le %%  la fin.\n");
                                    Efface_char(ligne,"%");
                                    Efface_char(ligne,"%");
                                    valeur1 = atoi(ligne);
                                    Efface_char(ligne,"/");
                                    valeur2 = atoi(ligne);
                                    if(valeur2 < valeur1)
                                        Erreur_aff(erreur,1,lignes,"Pour les probabilits de variation des prcipitations, la deuxime valeur est infrieure  la premire\n");
                                    if(valeur2 == valeur1)
                                        Erreur_aff(avert,2,lignes,"Pour les probabilits de variation des prcipitations, les 2 valeurs sont identique, vrifiez que ce n'est pas une erreur\n");
                                    if(valeur2 > 100)
                                        Erreur_aff(avert,2,lignes,"Pour les probabilits de variation du prcipitations, la deuxime valeur est suprieure  100.\n");
                                    j=0;
                                    while(isdigit(ligne[j++])); //Saute tout les chiffres
                                    if(ligne[j-1] != '.')
                                        Erreur_aff(erreur,1,lignes,"Aprs les probabilits de prcipitation, on doit trouver le . qui termine la ligne.\n");
                                    fin_cond=1; //La ligne se termine
                                }
                            }
                        }while(!fin_cond);
                    }
                }
                fgets(ligne,255,fichiercl); //Prend la ligne qui sera traite
                lignes++;  //Compte le nombre de lignes lues
            }while(ligne[0] != '<'); //Jusqu' ce que la ligne commence par <
            //Fin de la boucle de vrification des conditions de prcipitations
            for(i=1;i<=prec[0][0];i++) //prec[0][0] contient le nombre total de prcipitation
            {
                if(prec[0][i])
                {
                    if(!prec[1][i]) //Si prec[1][] == 0, alors la prcipitation n'a pas eu de ligne sans conditions
                    {
                        sprintf(chaine,"La prcipitation %.d n'a aucune ligne sans condition. Cette prcipitation risque de rester bloque.\n", prec[0][i]);
                        Erreur_aff(avert,2,lignes,chaine);
                    }
                }
            }
        }
        //Horloge vague
        if(verif == 13)
        {
            verif++;
            fin_cond=0;
            while(!strstr(ligne,"#Horloge vague:"))
            {   //Cherche #Horloge vague:
                if(fgets(ligne,255,fichiercl)) //Prend la ligne qui sera traite
                    lignes++;  //Compte le nombre de lignes lues
                else
                {
                    Erreur_aff(erreur,1,lignes,"Impossible de trouver le paragraphe Horloge vague.\n Identifi par '#Horloge vague:'\n");
                    fin_cond = 1;
                    break;
                }
            };
            if(!fin_cond)
            {
                //Vrification des lignes de l'horloge vague
                fgets(ligne,255,fichiercl); //Prend la ligne qui sera traite
                lignes++;  //Compte le nombre de lignes lues
                if(!strstr(ligne,"="))
                    Erreur_aff(erreur,1,lignes,"La ligne suivant '#Horloge vague:' doit tre la ligne du total, contenant '='.\n");
                else
                {   //Lit le total indiqu
                    Efface_char(ligne,"=");
                    valeur1 = atof(ligne);
                }
                fgets(ligne,255,fichiercl); //Prend la premire ligne des moments
                val_chiffre = 0;
                while(isdigit(ligne[0]))    //Arrte la boucle si la ligne ne commence pas par un chiffre.
                {
                    if(atoi(ligne) != val_chiffre+1)
                        Erreur_aff(erreur,1,lignes,"Les numros des moments ne se suivent pas.");
                    val_chiffre = atoi(ligne);
                    Efface_char(ligne,":");
                    j=0;
                    while(ligne[j] != ':')  //Tant qu'il reste du texte dans le calcul
                    {
                        if(!isdigit(ligne[j]) && ligne[j] != '$' && ligne[j] != '+' && ligne[j] != '-' && ligne[j] != '/' && ligne[j] != '*' && ligne[j] != '(' && ligne[j] != ')')
                        {
                            sprintf(chaine,"Le caractre %c n'est pas reconnu comme caractre  interprter.", ligne[j]);
                            Erreur_aff(erreur,1,lignes,chaine);
                        }
                        if(ligne[j] == '$')     //Prsence d'une variable
                        {
                            j++;    //Saute le $
                            k=0;
                            while(ligne[j] != '$')
                            {   //recopie la variable jusqu'au prochain $
                                chaine[k++] = ligne[j++];
                            }
                            chaine[k] = '\0'; //Termine la chaine
                            k=0;    //Par dfaut la variable n'est pas reconnue
                            if(!strcmp(chaine,"lever"))
                                k=1;
                            if(!strcmp(chaine,"coucher"))
                                k=1;
                            if(!strcmp(chaine,"deb_astro"))
                                k=1;
                            if(!strcmp(chaine,"fin_astro"))
                                k=1;
                            if(!strcmp(chaine,"deb_naut"))
                                k=1;
                            if(!strcmp(chaine,"fin_naut"))
                                k=1;
                            if(!strcmp(chaine,"deb_civil"))
                                k=1;
                            if(!strcmp(chaine,"fin_civil"))
                                k=1;
                            if(!k)
                            {
                                sprintf(chaine,"La variable '%s' n'est pas reconnue.", chaine);
                                Erreur_aff(erreur,1,lignes,chaine);
                            }
                        }
                        j++;    //Passe au caractre suivant
                    };
                    Efface_char(ligne,":"); //Passe  la variation de temprature
                    if(ligne[0] != 't')   //Si on trouve pas t aprs le premier :
                        Erreur_aff(erreur,1,lignes,"Juste aprs le deuxime :, impossible de trouver le t qui prcde la variation de temprature.\n");
                    if(!isdigit(ligne[1]) && ligne[1] != '-' && ligne[1] != '+')   //Si aprs t il n'y a pas un chiffre, un - ou un +
                        Erreur_aff(erreur,1,lignes,"Impossible de trouver la variation de temprature li  ce moment de la journe.\n");
                    else if(ligne[1] == '-' || ligne[1] == '+')
                    {   //En cas de - ou de +
                        if(!isdigit(ligne[2]))   //Vrifie qu'il y ai bien un chiffre aprs
                            Erreur_aff(erreur,1,lignes,"Impossible de trouver la variation de temprature li  ce moment de la journe.\n");
                    }
                    Efface_char(ligne,":"); //Passe  l'affichage
                    Efface_n(ligne);
                    if(strlen(ligne) > 33)
                        Erreur_aff(avert,2,lignes,"Le texte  afficher est trop long, il sera tronqu  33 caractres maximum.\n");
                    fgets(ligne,255,fichiercl); //Prend la ligne suivante
                };
                if(val_chiffre != valeur1)
                    Erreur_aff(avert,2,lignes,"Le nombre de moment lus ne correspond pas au total annonc.\n");
            }
        }
    }
}

void Erreur_aff (int* incr, int err_avert, int lignes, const char chaine[255])
{
    FILE* error_log;
    error_log = ouvre_fichier("Erreur.log","a");    //Ouvre le fichier de log  la fin pour criture  la suite
    *incr = *incr+1;
    if(err_avert==1)
    {
        printf("- Erreur ligne %d. ",lignes);
        fprintf(error_log,"- Erreur ligne %d. ",lignes);
    }
    else
    {
        printf("- Avertissement ligne %d. ", lignes);
        fprintf(error_log,"- Avertissement ligne %d. ", lignes);
    }
    putsacc(chaine);
    fprintf(error_log,"%s",chaine);
    fclose(error_log);
}
